{% extends 'snowebsvg/collections/separator_top/wave/top_1.html' %}
{% load svg_utils %}

{% block svg_content %}
    <g transform="{% scale 1 -1 %}">
        {{ block.super }}
    </g>
{% endblock %}
